@@ -1,20 +1,20 @@
 class Formatador
-  def display_table(hashes, keys = nil, &block)
+  def display_table(hashes, keys = nil, **options, &block)
     new_hashes = hashes.inject([]) do |accum,item|
       accum << :split unless accum.empty?
       accum << item
     end
-    display_compact_table(new_hashes, keys, &block)
+    display_compact_table(new_hashes, keys, **options, &block)
   end
 
-  def display_compact_table(hashes, keys = nil, &block)
+  def display_compact_table(hashes, keys = nil, **options, &block)
     headers = keys || []
     widths = {}
 
     # Calculate Widths
     if hashes.empty? && keys
       keys.each do |key|
-        widths[key] = key.to_s.length
+        widths[key] = length(key)
       end
     else
       hashes.each do |hash|
@@ -24,7 +24,7 @@ class Formatador
           if !keys
             headers << key
           end
-          widths[key] = [ length(key), widths[key] || 0, length(calculate_datum(key, hash)) || 0].max
+          widths[key] = [length(key), widths[key] || 0, length(calculate_datum(key, hash)) || 0].max
         end
         headers = headers.uniq
       end
@@ -52,25 +52,25 @@ class Formatador
     # Display data row
     columns = []
     headers.each do |header|
-      columns << "[bold]#{header}[/]#{' ' * (widths[header] - header.to_s.length)}"
+      columns << "[bold]#{header}[/]#{' ' * (widths[header] - length(header))}"
     end
     display_line("| #{columns.join(' | ')} |")
     display_line(split)
 
     hashes.each do |hash|
       if hash.respond_to? :keys
-        columns = []
-        headers.each do |header|
+        columns = headers.map do |header|
           datum = calculate_datum(header, hash)
           width = widths[header] - length(datum)
           width = width < 0 ? 0 : width
-          columns << "#{datum}#{' ' * width}"
+
+          datum.is_a?(Numeric) && options[:numeric_rjust] ? "#{' ' * width}#{datum}" : "#{datum}#{' ' * width}"
         end
         display_line("| #{columns.join(' | ')} |")
       else
         if hash == :split
           display_line(split)
-        end 
+        end
       end
       nil
     end
@@ -80,7 +80,10 @@ class Formatador
   private
 
   def length(value)
-    value.to_s.gsub(PARSE_REGEX, '').length
+    Reline::Unicode.calculate_width(value.to_s.gsub(PARSE_REGEX, ''))
+
+  rescue NotImplementedError
+    value.to_s.gsub(PARSE_REGEX, '').chars.reduce(0) { |sum, char| sum += char.bytesize > 1 ? 2 : 1 }
   end
 
   def calculate_datum(header, hash)
@@ -91,7 +94,7 @@ class Formatador
         datum = d[split] || d[split.to_sym] || ''
       end
     else
-      datum = hash[header] || ''
+      datum = hash.fetch(header, '')
     end
     datum
   end
