@@ -5,6 +5,18 @@ require 'rubygems'
 require 'shindo'
 require 'stringio'
 
+class IO
+  def tty?
+    true
+  end
+end
+
+class StringIO
+  def tty?
+    true
+  end
+end
+
 def capture_stdout
   old_stdout = $stdout
   new_stdout = StringIO.new
